/*
Programmer: McNeel
Date started: 10/02/2003
This program creates a SAS transport file of the Complete and Partial Extended
  records combined.
10/23/2003:
  Now using new data submission from Westat received from Bradford Hesse
    10/20/03 (it includes replicate weights).
  Formats were changed to eliminate grouping of values.
  Label of SPAgeRange was changed.
  Variables that have no value in any record were dropped.
11/13/2003:
  'Proc format' line was moved from the format file to this program.
  Variables AgeGrp, DistressScore, Distressed, HHIncA, HHIncB, Race, and RaceEthn were added.
02/04/2004:
  Label of HC8EAttendInternet was changed.
  Geographic variables were added.
  2003 rural-urban continuum codes from http://www.ers.usda.gov/briefing/rurality/RuralUrbCon/
    were added.
03/23/2004:
  Minor capitalization and spelling corrections were made to many of the formats.
  HC26fBookmarkSite was renamed HC26eLookedHealthInfo and the label was changed to "Looked for
    health information?".
  CK13eFoodAdditives was renamed CK13ePesticidesAdditives and the label was changed to "Do
    pesticides or food additives increase your chance of cancer?".
  DM3aChildrenUnder5Years was renamed DM3aChildrenUnder18Years.
  HC26fBookmarkSite was renamed HC26eLookedHealthInfo.
  HC26hAnythingElseOnline was renamed HC26gAnythingElseOnline.
  HC26hAnythingElseOnline_OS was renamed HC26gAnythingElseOnline_OS.
  Minor corrections were made to the labels of CaseNo and HC16hPublication.
06/24/2004:
  Several variable names were changed:
    CC10WhyNotBloodStool_OS was renamed CC10WhyNotStoolBlood_OS.
    CC11ThoughtBloodStool was renamed CC11ThoughtStoolBlood.
    CC12PlanBloodStool was renamed CC12PlanStoolBlood.
    CC13WhenNextBloodStool was renamed CC13WhenNextStoolBlood.
    CC14AgeBloodStool was renamed CC14AgeStoolBlood.
    CC15FreqBloodStool was renamed CC15FreqStoolBlood.
    CC15FreqBloodStool_OS was renamed CC15FreqStoolBlood_OS.
    Ck13nRaceEthnicity was renamed CK13nRaceEthnicity (capitalization change only).
    Ck13oLittleExercise was renamed CK13oLittleExercise (capitalization change only).
    Ck13sRadon was renamed CK13sRadon (capitalization change only).
    CK14cTooManyRecommendtions was renamed CK14cTooManyRecommendations.
    PC2RelativeChanceProstateCance was renamed PC2RelativeChanceProstateCancer.
  Interview and Person were dropped--these variables were left over from the sampling process.
  InterviewDate was added from the Screener dataset.
  HC14A and HC14B were added.
02/18/2005:
  The following variables were added:
    DMA
    CH3Age
    FV1Fruit_t
    FV2FruitJuice_t
    FV3Vegetables_t
    FV3aPotatoes_t
    HC12LastLookCancer_t
    HW1HeightInches_t
    AgeGrp5
    BMI
    TimeSinceDx
    CancerType
    SelfProxy
    TimeSinceInfo
03/09/2005: Restored the variable FIPS, which had been accidentally dropped in the last version.
03/28/2005:
  The variables FV1Fruit_t, FV2FruitJuice_t, FV3Vegetables_t, and FV3aPotatoes_t
    were changed from times per month to times per day.
04/11/2005:
  The variables FV1Fruit_t, FV2FruitJuice_t, FV3Vegetables_t, and FV3aPotatoes_t
    were changed so they are no longer rounded.
06/02/2006:
  The following changes were made so that the data would be consistent with HINTS 2005:
	"Never" category in the variables FV1Fruit_t, FV2FruitJuice_t, FV3Vegetables_t, and FV3aPotatoes_t
		changed to "0" Times Per Day
	FV1Fruit_t renamed to Fruits
  	FV2FruitJuice_t renamed to FruitJuice
  	FV3Vegetables_t renamed to Vegetables
  	FV3aPotatoes_t renamed to Potatoes
  	Revised coding of CH3Age and BMI
  	CH3Age renamed to AgeDX
  	AgeGrp renamed to AgeGrpA
  	AgeGrp5 renamed to AgeGrpB
	HC12LastLookCancer_t renamed DaysSinceInfo
	Added Recode EducA
  	The Ref/DK/NA/Missing categories were changed for Distressed, DistressScore, BMI, TimeSinceDX,
  		CancerType, HHIncA, HHIncB, FV1Fruit_t, FV2FruitJuice_t, FV3Vegetables_t, FV3aPotatoes_t,
  		TimeSinceInfo, SelfProxy, and RacEthn
*/
options nocenter ls=256 noovp orientation=landscape;
footnote 'Program: /prj/brp/hints/data/2003/progs/create.hints2003.d2006_06_02.public.sas';

title '2003 HINTS Extended Data, June 02 2006 Public Version';

***Input files;
libname RAW '/prj/brp/hints/data/2003/sasdata/raw/';  ***Contains geographic data;
filename COMPLETE '/prj/brp/hints/data/2003/sasdata/raw/Hints_Completes_2003_w.cpt';
filename PARTIAL '/prj/brp/hints/data/2003/sasdata/raw/Hints_Parital_Completes_2003_w.cpt';
filename SCREENER '/prj/brp/hints/data/2003/sasdata/raw/Hints_Screener_2003.cpt';
filename RURALURB '/prj/brp/hints/data/misc/RuralUrbanCodes2003.csv';
filename HC14 '/prj/brp/hints/data/2003/otherdata/hc14.2004_06_24.csv';
filename FIPSDMA '/prj/brp/hints/data/misc/fips_dma.csv';
filename CANCTYPE '/prj/brp/hints/moser/cancertype.12-22-2004.v8x';
filename FORMATS '/prj/brp/hints/data/2003/progs/formats.hints2003.d2006_06_02.public.sas';
***Output files;
filename OUTFILE1 pipe 'gzip -c > /prj/brp/hints/data/2003/sasdata/hints2003.d2006_06_02.public.v8x.gz';
filename CONTENTS 'contents.hints2003.d2006_06_02.public.pdf';
filename SOURCE 'frequencies.hints2003.d2006_06_02.public.rtf';

proc format;
%include FORMATS;

proc cimport file=COMPLETE data=complete;
proc cimport file=PARTIAL  data=partial;

data extended;
  set complete partial;

  ***Correct labels from the original dataset;
  label
    caseno = 'Household ID'
    ck13efoodadditives = 'Do pesticides or food additives increase your chance of cancer?'
    hc8eattendinternet = 'Attention paid to the Internet?'
    hc16hpublication = 'Would you like to read a book, magazine, or publication for cancer info?'
    hc26fbookmarksite = 'Looked for health information?'
    spagerange = 'What is your age range?'
    ;

  ***Correct variable names from the original dataset;
  rename
    CC10WhyNotBloodStool_OS = CC10WhyNotStoolBlood_OS
    CC11ThoughtBloodStool = CC11ThoughtStoolBlood
    CC12PlanBloodStool = CC12PlanStoolBlood
    CC13WhenNextBloodStool = CC13WhenNextStoolBlood
    CC14AgeBloodStool = CC14AgeStoolBlood
    CC15FreqBloodStool = CC15FreqStoolBlood
    CC15FreqBloodStool_OS = CC15FreqStoolBlood_OS
    CK13eFoodAdditives = CK13ePesticidesAdditives
    Ck13nRaceEthnicity = CK13nRaceEthnicity
    Ck13oLittleExercise = CK13oLittleExercise
    Ck13sRadon = CK13sRadon
    CK14cTooManyRecommendtions = CK14cTooManyRecommendations
    DM3aChildrenUnder5Years = DM3aChildrenUnder18Years
    HC26fBookmarkSite = HC26eLookedHealthInfo
    HC26hAnythingElseOnline = HC26gAnythingElseOnline
    HC26hAnythingElseOnline_OS = HC26gAnythingElseOnline_OS
    PC2RelativeChanceProstateCance = PC2RelativeChanceProstateCancer
    ;

  drop Interview Person;
run;

data extended(drop=i);
  set extended;
  format
    Rslt                             $RsltF.
    SpanEng                          $SpanEnF.
    SPage                             SPageF.
    SPAgeRange                        SPAgeRF.
    SPGender                          SPGendF.
    HC1UsualProvider                  HC1UsuF.
    HC2ProviderType                   HC2ProF.
    HC3FreqGoProvider                 HC3FreF.
    HC4aProviderListen                HC4aPrF.
    HC4bProviderExplain               HC4aPrF.
    HC4cProviderRespect               HC4aPrF.
    HC4dProviderTime                  HC4aPrF.
    HC4eProviderInvolve               HC4aPrF.
    HC5Cable                          HC1UsuF.
    HC6aWatchTV                       HC6aWaF.
    HC6bListenRadio                   HC6bLiF.
    HC7aReadNewspaper                 HC7aReF.
    HC7bReadMagazine                  HC7bReF.
    HC8aAttendTV                      HC8aAtF.
    HC8bAttendRadio                   HC8aAtF.
    HC8cAttendNewspaper               HC8aAtF.
    HC8dAttendMagazines               HC8aAtF.
    HC8eAttendInternet                HC8aAtF.
    HC9SeekCancerInfo                 HC1UsuF.
    HC10OtherSeekCancerInfo           HC1UsuF.
    HC11WhoSeekCancerInfo             HC11WhF.
    HC12LastLookCancerInfo            HC12LaF.
    HC12LastLookCancerInfo_Unit       HC12LaG.
    HC13WhereLookCancerInfo           HC13WhF.
    HC14WhatLookCancerInfo           $HC2ProG.
    HC15WhereGoFirst                  HC15WhF.
    HC15AConfidenceGetCancerInfo      HC15ACF.
    HC16aPersonalComputer             HC1UsuF.
    HC16a1InternetSiteLike            HC1UsuF.
    HC16bVideoTape                    HC1UsuF.
    HC16cAudioTape                    HC1UsuF.
    HC16dPersonalizedPrint            HC1UsuF.
    HC16eCDROM                        HC1UsuF.
    HC16fTelephoneCall                HC1UsuF.
    HC16gInPerson                     HC1UsuF.
    HC16hPublication                  HC1UsuF.
    HC16iAnotherSource                HC1UsuF.
    HC18aTrustDoctor                  HC8aAtF.
    HC18bTrustFriendsFamily           HC8aAtF.
    HC18cTrustNewspaper               HC8aAtF.
    HC18dTrustMagazines               HC8aAtF.
    HC18eTrustRadio                   HC8aAtF.
    HC18fTrustInternet                HC8aAtF.
    HC18gTrustTelevision              HC8aAtF.
    HC19aWantMoreInfo                 HC19aWF.
    HC19bAlotEffort                   HC19aWF.
    HC19cNoTime                       HC19cNF.
    HC19eFrustrated                   HC19cNF.
    HC19gConcernedQuality             HC19cNF.
    HC19jTooHardUnderstand            HC19cNF.
    HC19kSatisfied                    HC19cNF.
    HC20UseInternet                   HC1UsuF.
    HC21aNotInterested                HC1UsuF.
    HC21bCannotAfford                 HC1UsuF.
    HC21cTooComplicated               HC1UsuF.
    HC21dNotUseful                    HC1UsuF.
    HC22InternetHome                  HC1UsuF.
    HC23AccessInternet                HC23AcF.
    HC24aHealthInfoSelf               HC1UsuF.
    HC24bHealthInfoOther              HC1UsuF.
    HC25FreqInternetHealth            HC25FrF.
    HC26aBuyMedicine                  HC1UsuF.
    HC26bSupportGroup                 HC1UsuF.
    HC26cTalkDoctor                   HC1UsuF.
    HC26eLookedHealthInfo             HC1UsuF.
    HC26gAnythingElseOnline           HC1UsuF.
    HC27LastOnlineHealth              HC27LaF.
    HC28WhereLastOnline               HC28WhF.
    HC29InternetForCancer             HC1UsuF.
    HC30HowInternetForCancer          HC30HoF.
    HC31UsefulInternetForCancer       HC31UsF.
    HC32FreqInternetForCancer         HC32FrF.
    HC33WhyUseInternet1               HC33WhF.
    HC33WhyUseInternet2               HC33WhF.
    HC33WhyUseInternet3               HC33WhF.
    HC33WhyUseInternet4               HC33WhF.
    HC33WhyUseInternet5               HC33WhF.
    HC33WhyUseInternet6               HC33WhF.
    HC34aNIH                          HC1UsuF.
    HC34bACS                          HC1UsuF.
    HC34cCIS                          HC1UsuF.
    HC34dNCI                          HC1UsuF.
    HC34eCancerHotline                HC1UsuF.
    HC34fUSCenter                     HC1UsuF.
    CH1EverHadCancer                  HC1UsuF.
    CH2TypeOfSPsCancer01              CH2TypF.
    CH2TypeOfSPsCancer02              CH2TypF.
    CH2TypeOfSPsCancer03              CH2TypF.
    CH2TypeOfSPsCancer04              CH2TypF.
    CH2TypeOfSPsCancer05              CH2TypF.
    CH2TypeOfSPsCancer06              CH2TypF.
    CH2TypeOfSPsCancer07              CH2TypF.
    CH2TypeOfSPsCancer08              CH2TypF.
    CH2TypeOfSPsCancer09              CH2TypF.
    CH2TypeOfSPsCancer10              CH2TypF.
    CH2TypeOfSPsCancer11              CH2TypF.
    CH2TypeOfSPsCancer12              CH2TypF.
    CH2TypeOfSPsCancer13              CH2TypF.
    CH2TypeOfSPsCancer14              CH2TypF.
    CH2TypeOfSPsCancer15              CH2TypF.
    CH2TypeOfSPsCancer16              CH2TypF.
    CH2TypeOfSPsCancer17              CH2TypF.
    CH2TypeOfSPsCancer18              CH2TypF.
    CH2TypeOfSPsCancer19              CH2TypF.
    CH3WhenDiagnosedCancer_Unit       CH3WheF.
    CH3WhenDiagnosedCancer_Age        CH3WheG.
    CH3WhenDiagnosedCancer_Year       CH3WheH.
    CH4FamilyEverHadCancer            CH4FamF.
    CK1CauseMostDeaths                CK1CauF.
    CK4ReduceCancer1                  CK4RedF.
    CK4ReduceCancer2                  CK4RedF.
    CK4ReduceCancer3                  CK4RedF.
    CK4ReduceCancer4                  CK4RedF.
    CK4ReduceCancer5                  CK4RedF.
    CK4ReduceCancer6                  CK4RedF.
    CK4ReduceCancer7                  CK4RedF.
    CK4ReduceCancer8                  CK4RedF.
    CK4ReduceCancer9                  CK4RedF.
    CK5EatReduceCancer1               CK5EatF.
    CK5EatReduceCancer2               CK5EatF.
    CK5EatReduceCancer3               CK5EatF.
    CK5EatReduceCancer4               CK5EatF.
    CK5EatReduceCancer5               CK5EatF.
    CK5EatReduceCancer6               CK5EatF.
    CK5EatReduceCancer7               CK5EatF.
    CK5EatReduceCancer8               CK5EatF.
    CK6TestsReduceCancer01            CK6TesF.
    CK6TestsReduceCancer02            CK6TesF.
    CK6TestsReduceCancer03            CK6TesF.
    CK6TestsReduceCancer04            CK6TesF.
    CK6TestsReduceCancer05            CK6TesF.
    CK6TestsReduceCancer06            CK6TesF.
    CK6TestsReduceCancer07            CK6TesF.
    CK6TestsReduceCancer08            CK6TesF.
    CK6TestsReduceCancer09            CK6TesF.
    CK6TestsReduceCancer10            CK6TesF.
    CK8ChanceGetCancer                CK8ChaF.
    CK9WorryGetCancer                 CK9WorF.
    CK10ChangeBehavior1               CK4RedF.
    CK10ChangeBehavior2               CK4RedF.
    CK10ChangeBehavior3               CK4RedF.
    CK10ChangeBehavior4               CK4RedF.
    CK10ChangeBehavior5               CK4RedF.
    CK10ChangeBehavior6               CK4RedF.
    CK10ChangeBehavior7               CK4RedF.
    CK10ChangeBehavior8               CK4RedF.
    CK10ChangeBehavior9               CK4RedF.
    CK11ChangeDiet1                   CK5EatF.
    CK11ChangeDiet2                   CK5EatF.
    CK11ChangeDiet3                   CK5EatF.
    CK11ChangeDiet4                   CK5EatF.
    CK11ChangeDiet5                   CK5EatF.
    CK11ChangeDiet6                   CK5EatF.
    CK11ChangeDiet7                   CK5EatF.
    CK11ChangeDiet8                   CK5EatF.
    CK12GetTested01                   CK6TesF.
    CK12GetTested02                   CK6TesF.
    CK12GetTested03                   CK6TesF.
    CK12GetTested04                   CK6TesF.
    CK12GetTested05                   CK6TesF.
    CK12GetTested06                   CK6TesF.
    CK12GetTested07                   CK6TesF.
    CK12GetTested08                   CK6TesF.
    CK12GetTested09                   CK6TesF.
    CK12GetTested10                   CK6TesF.
    CK13aSmoking                      CK13aSF.
    CK13bHighFatDiet                  CK13aSF.
    CK13dExposureToSun                CK13aSF.
    CK13ePesticidesAdditives          CK13aSF.
    CK13gLowFiber                     CK13aSF.
    CK13hFewFruitsVegetables          CK13aSF.
    CK13iStress                       CK13iSF.
    CK13jAlcohol                      CK13aSF.
    CK13kHitBreast                    CK13aSF.
    CK13lManySexPartners              CK13lMF.
    CK13mFamilyHistory                CK13aSF.
    CK13nRaceEthnicity                CK13aSF.
    CK13oLittleExercise               CK13aSF.
    CK13rPollution                    CK13aSF.
    CK13sRadon                        CK13aSF.
    CK14aEverythingCausesCancer       HC19cNF.
    CK14bCannotLowerChances           HC19aWF.
    CK14cTooManyRecommendations       HC19aWF.
    CK15CancerCauseMostDeaths         CK15CaF.
    CC1ChanceColonCancer              CK8ChaF.
    CC2RelativeChanceColonCancer      CC2RelF.
    CC3FreqWorryColonCancer           CK9WorF.
    CC4TestsForColonCancer1           CC4TesF.
    CC4TestsForColonCancer2           CC4TesF.
    CC4TestsForColonCancer3           CC4TesF.
    CC4TestsForColonCancer4           CC4TesF.
    CC4TestsForColonCancer5           CC4TesF.
    CC4TestsForColonCancer6           CC4TesF.
    CC4TestsForColonCancer7           CC4TesF.
    CC4TestsForColonCancer8           CC4TesF.
    CC4TestsForColonCancer9           CC4TesF.
    CC4AEverHeardStoolBlood           HC1UsuF.
    CC5DoctorAdviseStoolBlood         HC1UsuF.
    CC6HadStoolBlood                  HC1UsuF.
    CC7WhenStoolBlood                 CC7WheF.
    CC9StoolBloodLast3Years           CC9StoF.
    CC10WhyNotStoolBlood01            CC10WhF.
    CC10WhyNotStoolBlood02            CC10WhF.
    CC10WhyNotStoolBlood03            CC10WhF.
    CC10WhyNotStoolBlood04            CC10WhF.
    CC10WhyNotStoolBlood05            CC10WhF.
    CC10WhyNotStoolBlood06            CC10WhF.
    CC10WhyNotStoolBlood07            CC10WhF.
    CC10WhyNotStoolBlood08            CC10WhF.
    CC10WhyNotStoolBlood09            CC10WhF.
    CC10WhyNotStoolBlood10            CC10WhF.
    CC10WhyNotStoolBlood11            CC10WhF.
    CC10WhyNotStoolBlood12            CC10WhF.
    CC11ThoughtStoolBlood             HC1UsuF.
    CC12PlanStoolBlood                CC12PlF.
    CC13WhenNextStoolBlood            CC13WhF.
    CC14AgeStoolBlood                 CC14AgF.
    CC15FreqStoolBlood                CC15FrF.
    CC15AEverHeardSigCol              HC1UsuF.
    CC16aHadSigmoidoscopy             HC1UsuF.
    CC16bHadColonoscopy               HC1UsuF.
    CC17aAdviseSigmoidoscopy          HC1UsuF.
    CC17bAdviseColonoscopy            HC1UsuF.
    CC18WhenSigCol                    CC18WhF.
    CC19SigColLast10Years             CC19SiF.
    CC20WhyNotSigCol01                CC20WhF.
    CC20WhyNotSigCol02                CC20WhF.
    CC20WhyNotSigCol03                CC20WhF.
    CC20WhyNotSigCol04                CC20WhF.
    CC20WhyNotSigCol05                CC20WhF.
    CC20WhyNotSigCol06                CC20WhF.
    CC20WhyNotSigCol07                CC20WhF.
    CC20WhyNotSigCol08                CC20WhF.
    CC20WhyNotSigCol09                CC20WhF.
    CC20WhyNotSigCol10                CC20WhF.
    CC20WhyNotSigCol11                CC20WhF.
    CC20WhyNotSigCol12                CC20WhF.
    CC21ThoughtSigCol                 HC1UsuF.
    CC22PlanSigCol                    CC22PlF.
    CC23WhenNextSigCol                CC23WhF.
    CC24AgeSigCol                     CC24AgF.
    CC25FreqSigCol                    CC25FrF.
    CC26aCheckColonEasy               HC19aWF.
    CC26bCheckColonAfraid             HC19aWF.
    CC26cCheckColonDetectEarly        HC19cNF.
    CC26dCheckColonTooExpensive       HC19cNF.
    CC27RiskColonCancer               CC27RiF.
    BC1ChanceBreastCancer             CK8ChaF.
    BC2RelativeChanceBreastCancer     BC2RelF.
    BC3FreqWorryBreastCancer          CK9WorF.
    BC4DoctorAdviseMammogram          HC1UsuF.
    BC5HadMammogram                   HC1UsuF.
    BC6WhenMammogram                  CC7WheF.
    BC8MammogramLast6Years            BC8MamF.
    BC9WhyNotMammogram01              BC9WhyF.
    BC9WhyNotMammogram02              BC9WhyF.
    BC9WhyNotMammogram03              BC9WhyF.
    BC9WhyNotMammogram04              BC9WhyF.
    BC9WhyNotMammogram05              BC9WhyF.
    BC9WhyNotMammogram06              BC9WhyF.
    BC9WhyNotMammogram07              BC9WhyF.
    BC9WhyNotMammogram08              BC9WhyF.
    BC9WhyNotMammogram09              BC9WhyF.
    BC9WhyNotMammogram10              BC9WhyF.
    BC9WhyNotMammogram11              BC9WhyF.
    BC10ThoughtMammogram              HC1UsuF.
    BC11PlanMammogram                 CC22PlF.
    BC12WhenNextMammogram             BC12WhF.
    BC13AgeMammogram                  BC13AgF.
    BC14FreqMammogram                 BC14FrF.
    CV1HadPapSmear                    HC1UsuF.
    CV2WhenPapSmear                   CV2WheF.
    CV4PapSmearLast6Years             CV4PapF.
    CV5Hysterectomy                   HC1UsuF.
    CV6WhenNextPapSmear               CV6WheF.
    PC1ChanceProstateCancer           CK8ChaF.
    PC2RelativeChanceProstateCancer   PC2RelF.
    PC3FreqWorryProstateCancer        CK9WorF.
    PC3AEverHeardPSATest              HC1UsuF.
    PC4DoctorAdvisePSATest            PC4DocF.
    PC5HadPSATest                     PC4DocF.
    PC6WhenPSATest                    CC7WheF.
    PC7PSALast5Years                  BC8MamF.
    TU1Smoke100                       HC1UsuF.
    TU2SmokeNow                       TU2SmoF.
    TU3SmokeDayAlways                 TU3SmoF.
    TU4SmokeDaySometimes              TU4SmoF.
    TU5PlanQuitSmoking                TU5PlaF.
    TU6WhenQuitSmoke                  TU6WheF.
    TU7SmokeDayFormer                 TU4SmoF.
    TU9aExercise                      HC19aWF.
    TU9bVitamins                      HC19aWF.
    TU9cFewYears                      HC19cNF.
    TU9dGenes                         HC19cNF.
    TU10TypeCigarette                 TU10TyF.
    TU11WhySmokeType                  TU11WhF.
    TU12WouldTryLessHarmfulCig        TU12WoF.
    TU13TriedLessHarmfulCig           HC1UsuF.
    TU14TriedSmokelessTobacco         HC1UsuF.
    TU15ChanceLungCancerGeneral       TU15ChF.
    TU16ChanceLungCancerSpecific      CK8ChaF.
    TU17FreqCuredLungCancer           TU17FrF.
    TU18RelChanceLungCancerGen        TU18ReF.
    TU19RelChanceLungCancerSpecifi    TU18ReF.
    FV1Fruits                         FV1FruF.
    FV1Fruits_Unit                    FV1FruG.
    FV2FruitJuice                     FV2FruF.
    FV2FruitJuice_Unit                FV1FruG.
    FV3Vegetables                     FV3VegF.
    FV3Vegetables_Unit                FV1FruG.
    FV3aPotatoes                      FV3VegF.
    FV3aPotatoes_Unit                 FV1FruG.
    FV4NumberServings                 FV4NumF.
    EX1AnyExercise                    HC1UsuF.
    EX2Sweat                          HC1UsuF.
    EX3ExerciseLowerCancer            EX3ExeF.
    EX4ExerciseLowerWhichCancer01     EX4ExeF.
    EX4ExerciseLowerWhichCancer02     EX4ExeF.
    EX4ExerciseLowerWhichCancer03     EX4ExeF.
    EX4ExerciseLowerWhichCancer04     EX4ExeF.
    EX4ExerciseLowerWhichCancer05     EX4ExeF.
    EX4ExerciseLowerWhichCancer06     EX4ExeF.
    EX4ExerciseLowerWhichCancer07     EX4ExeF.
    EX4ExerciseLowerWhichCancer08     EX4ExeF.
    EX4ExerciseLowerWhichCancer09     EX4ExeF.
    EX4ExerciseLowerWhichCancer10     EX4ExeF.
    EX4ExerciseLowerWhichCancer11     EX4ExeF.
    EX4ExerciseLowerWhichCancer12     EX4ExeF.
    EX4ExerciseLowerWhichCancer13     EX4ExeF.
    EX4ExerciseLowerWhichCancer14     EX4ExeF.
    EX4ExerciseLowerWhichCancer15     EX4ExeF.
    EX4ExerciseLowerWhichCancer16     EX4ExeF.
    EX4ExerciseLowerWhichCancer17     EX4ExeF.
    EX4ExerciseLowerWhichCancer18     EX4ExeF.
    EX4ExerciseLowerWhichCancer19     EX4ExeF.
    EX4ExerciseLowerWhichCancer20     EX4ExeF.
    HW1Height_Feet                    HW1HeiF.
    HW1Height_Inches                  HW1HeiG.
    HW2Weight                         HW2WeiF.
    HS1GeneralHealth                  HS1GenF.
    HS2aSad                           HS2aSaF.
    HS2bNervous                       HS2aSaF.
    HS2cRestless                      HS2aSaF.
    HS2dHopeless                      HS2aSaF.
    HS2eEffort                        HS2aSaF.
    HS2fWorthless                     HS2aSaF.
    HS3DepressionInterfere            HC8aAtF.
    HS5HealthInsurance                HC1UsuF.
    DM1MainActivity                   DM1MaiF.
    DM2MaritalStatus                  DM2MarF.
    DM3aChildrenUnder18Years          HC1UsuF.
    DM4Hispanic                       HC1UsuF.
    DM5Race1                          DM5RacF.
    DM5Race2                          DM5RacF.
    DM5Race3                          DM5RacF.
    DM5Race4                          DM5RacF.
    DM5Race5                          DM5RacF.
    DM6Education                      DM6EduF.
    DM7aIncome25Thousand              HC1UsuF.
    DM7bIncome20Thousand              HC1UsuF.
    DM7cIncome15Thousand              HC1UsuF.
    DM7dIncome10Thousand              HC1UsuF.
    DM7eIncome35Thousand              HC1UsuF.
    DM7fIncome50Thousand              HC1UsuF.
    DM7gIncome75Thousand              HC1UsuF.
    DM7hIncomeOver75Thousand          HC1UsuF.
    ;

  ***Drop variables that have no value in any record;
  drop
    HC33WhyUseInternet6
    CH2TypeofSPsCancer05-CH2TypeofSPsCancer19
    CK4ReduceCancer_4OS
    CK4ReduceCancer_5OS
    CK4ReduceCancer_6OS
    CK4ReduceCancer_7OS
    CK4ReduceCancer_8OS
    CK6TestsReduceCancer09
    CK6TestsReduceCancer10
    CK10ChangeBehavior7-CK10ChangeBehavior9
    CK10ChangeBehavior_3OS
    CK10ChangeBehavior_4OS
    CK10ChangeBehavior_5OS
    CK10ChangeBehavior_6OS
    CK10ChangeBehavior_7OS
    CK10ChangeBehavior_8OS
    CK11ChangeDiet8
    CK12GetTested06-CK12GetTested10
    CC4TestsForColonCancer7-CC4TestsForColonCancer9
    CC10WhyNotStoolBlood04-CC10WhyNotStoolBlood12
    CC20WhyNotSigCol06-CC20WhyNotSigCol12
    BC9WhyNotMammogram04-BC9WhyNotMammogram11
    EX4ExerciseLowerWhichCancer18-EX4ExerciseLowerWhichCancer20
    ;

  label AgeGrp = 'Age Group (Version A)';
  format AgeGrp AgeGrpA.;
  if 18<=spage<=34 or spagerange=2 then agegrp=1;
  else if 35<=spage<=39 or spagerange=3 then agegrp=2;
  else if 40<=spage<=44 or spagerange=4 then agegrp=3;
  else if 45<=spage<997 or spagerange=5 then agegrp=4;

	label EducA = "What is the highest level of school you completed?";
	select (DM6Education);
		when (1,2,3)						EducA=1;*<HS;
		when (4)							EducA=2;*=HS;
		when (5)							EducA=3;*<CG;
		when (6)							EducA=4;*>=CG;
		otherwise							EducA=DM6Education;
		end;
	format EducA educaf.;

  ***Psychological distress composite based on NHIS (see http://www.cdc.gov/nchs/data/nhis/earlyrelease/200309_13.pdf);
  ***Modified from "Respondent Characteristics.sas" from Bradford Hesse 10/23/2003;
  label DistressScore = 'Psychological distress composite score';
  array a_stressed[6] HS2aSad HS2bNervous HS2cRestless HS2dHopeless HS2eEffort HS2fWorthless;
  DistressScore = 0;
  do i=1 to 6;
    if a_stressed[7-i] in (7,8,9) then do;
      DistressScore=a_stressed[7-i]+90;
      leave;
      end;
  	else DistressScore = DistressScore + (5 - a_stressed[i]);
  	end;
  format DistressScore RefDkNa.;

  label Distressed = 'Serious psychological distress';
  format Distressed Distress.;
  if 0<=DistressScore<=12 then Distressed = 0; ***No;
  else if 13<=DistressScore<=24 then Distressed = 1; ***Yes;
  else if DistressScore in (97,98,99) then Distressed=DistressScore-90;

	array check[8] DM7hIncomeOver75Thousand DM7gIncome75Thousand DM7fIncome50Thousand
					DM7eIncome35Thousand DM7dIncome10Thousand DM7cIncome15Thousand
					DM7bIncome20Thousand DM7aIncome25Thousand;

  ***In HHIncA, people with incomes < $25,000 who refused or didn't know a specific category were categorized as ref/na/dk/missing;
  label HHIncA = 'Annual household income (version A)';
  format HHIncA HHIncA.;
  if DM7dIncome10Thousand=1 then HHIncA=1; ***< $10,000;
  else if DM7dIncome10Thousand=2 and DM7cIncome15Thousand=1 then HHIncA=2; ***$10,000 to < $15,000;
  else if DM7cIncome15Thousand=2 and DM7bIncome20Thousand=1 then HHIncA=3; ***$15,000 to < $20,000;
  else if DM7bIncome20Thousand=2 and DM7aIncome25Thousand=1 then HHIncA=4; ***$20,000 to < $25,000;
  else if DM7eIncome35Thousand=1 then HHIncA=5; ***$25,000 to < $35,000;
  else if DM7fIncome50Thousand=1 then HHIncA=6; ***$35,000 to < $50,000;
  else if DM7gIncome75Thousand=1 then HHIncA=7; ***$50,000 to < $75,000;
  else if DM7hIncomeOver75Thousand=1 then HHIncA=8; ***>= $75,000;
  else do i=1 to 8;
    if check[i] in (7,8,9) then do;
	  HHIncA=check[i]+90;
	  leave;
	  end;
	end;

  ***In HHIncB, people with incomes < $25,000 are grouped as < $25,000 whether or not they refused or didn't know a specific category;
  label HHIncB = 'Annual household income (version B)';
  format HHIncB HHIncB.;
  if DM7aIncome25Thousand=1 then HHIncB=1; ***< $25,000;
  else if DM7eIncome35Thousand=1 then HHIncB=2; ***$25,000 to < $35,000;
  else if DM7fIncome50Thousand=1 then HHIncB=3; ***$35,000 to < $50,000;
  else if DM7gIncome75Thousand=1 then HHIncB=4; ***$50,000 to < $75,000;
  else if DM7hIncomeOver75Thousand=1 then HHIncB=5; ***>= $75,000;
  else do i=1 to 8;
    if check[i] in (7,8,9) then do;
	  HHIncB=check[i];
	  leave;
	  end;
	end;

  label Race = 'Race';
  format race race.;
  if 10<=dm5race2<=14 then race=6; ***Multiple races mentioned;
  else if dm5race1=14 then race=1; ***White;
  else if dm5race1=12 then race=2; ***Black or African American;
  else if dm5race1=10 then race=3; ***American Indian or Alaska Native;
  else if dm5race1=11 then race=4; ***Asian;
  else if dm5race1=13 then race=5; ***Native Hawaiian or other Pacific Islander;
  else if dm5race1=98 then race=7; ***Refused;
  else if dm5race1=99 then race=8; ***Don't know;

  label RaceEthn = 'Race/ethnicity';
  format raceethn raceethn.;
  if dm4hispanic=1 then raceethn=1; ***Hispanic;
  else if dm4hispanic=2 and 1<=race<=6 then raceethn=race+1; ***Non-Hispanic, various races;
  else if race in (7,8) then raceethn=dm5race1;
  else if dm4hispanic gt 2 then raceethn=dm4hispanic+90;

  label
    FV1Fruit_t      = 'How often did you eat fruits? (times per day)'
    FV2FruitJuice_t = 'How often did you drink fruit juice? (times per day)'
    FV3Vegetables_t = 'How often did you eat vegetables? (times per day)'
    FV3aPotatoes_t  = 'How often did you eat potatoes? (times per day)'
    ;
  format FV1Fruit_t FV2FruitJuice_t FV3Vegetables_t FV3aPotatoes_t RefDkNa.;
  array a_foodcnt[4]    FV1Fruits      FV2FruitJuice      FV3Vegetables      FV3aPotatoes;
  array a_foodunit[4]   FV1Fruits_Unit FV2FruitJuice_Unit FV3Vegetables_Unit FV3aPotatoes_Unit;
  array a_foodperday[4] FV1Fruit_t     FV2FruitJuice_t    FV3Vegetables_t    FV3aPotatoes_t;
  do i = 1 to 4;
    if      a_foodcnt[i]=95 then a_foodperday[i] = 0;***None;
    else if a_foodcnt[i]=98 then a_foodperday[i] = 98; ***Refused;
    else if a_foodcnt[i]=99 then a_foodperday[i] = 99; ***Don't know;
    else if a_foodunit[i]=1 then a_foodperday[i] = a_foodcnt[i];
    else if a_foodunit[i]=2 then a_foodperday[i] = a_foodcnt[i]/7;
    else if a_foodunit[i]=3 then a_foodperday[i] = a_foodcnt[i]/30;
  end;

  label HC12LastLookCancer_t = 'How long ago did you seek cancer information? (days)';
  format HC12LastLookCancer_t DaysSinc.;
  if      HC12LastLookCancerInfo=98     then HC12LastLookCancer_t = 99998; ***Refused;
  else if HC12LastLookCancerInfo=99     then HC12LastLookCancer_t = 99999; ***Don't know;
  else if HC12LastLookCancerInfo_Unit=1 then HC12LastLookCancer_t = HC12LastLookCancerInfo;
  else if HC12LastLookCancerInfo_Unit=2 then HC12LastLookCancer_t = HC12LastLookCancerInfo*7;
  else if HC12LastLookCancerInfo_Unit=3 then HC12LastLookCancer_t = HC12LastLookCancerInfo*30;
  else if HC12LastLookCancerInfo_Unit=4 then HC12LastLookCancer_t = round(HC12LastLookCancerInfo*365.25);

  label HW1HeightInches_t = 'Height without shoes in inches';
  format HW1HeightInches_t HW1a.;
  if      HW1Height_Feet=98 then HW1HeightInches_t = 998; ***Refused;
  else if HW1Height_Feet=99 then HW1HeightInches_t = 999; ***Don't know;
  else                           HW1HeightInches_t = HW1Height_Feet*12 + HW1Height_Inches;

  label AgeGrp5 = 'Age Group (Version B)';
  format AgeGrp5 AgeGrpB.;
  if      18<=spage<=34 or  spagerange in (2)   then agegrp5=1;
  else if 35<=spage<=49 or  spagerange in (3 4) then agegrp5=2;
  else if 50<=spage<=64                         then agegrp5=3;
  else if 65<=spage<=74                         then agegrp5=4;
  else if 75<=spage<997                         then agegrp5=5;
  else if     spage=998 and spagerange in (5)   then agegrp5=8; ***45 or older, exact age refused;
  else if     spage=999 and spagerange in (5)   then agegrp5=9; ***45 or older, exact age unknown;

  ***  Algorithm for BMI supplied by the Centers for Disease Control - Department of Health & Human Services  ***;
  ***  See the following website --> http://www.cdc.gov/nccdphp/dnpa/bmi/adult_BMI/about_adult_BMI.htm        ***;
  if HW2Weight ge 997 then BMI=HW2Weight;
  else if HW1Height_Inches ge 97 then BMI=HW1Height_Inches+900;
  else if HW1Height_Feet ge 97 then BMI=HW1Height_Feet+900;
  else BMI=round(703*HW2Weight/((12*HW1Height_Feet + HW1Height_Inches)*(12*HW1Height_Feet + HW1Height_Inches)),.1);
  label BMI = '-->BMI. Body Mass Index (HW1-HW2 Recode)';
  format BMI SpAge.;

  ***Code for SelfProxy was suppplied by Richard Moser 02/15/2005;
  label SelfProxy = 'Did they look for information themselves, by proxy, both or neither';
  format selfproxy selfprox.;
  if hc9seekcancerinfo=1 and HC10otherseekcancerinfo=1 then selfproxy=1;
  else if hc9seekcancerinfo=1 and HC10otherseekcancerinfo=2 then selfproxy=2;
  else if hc9seekcancerinfo=2 and HC10otherseekcancerinfo=1 then selfproxy=3;
  else if hc9seekcancerinfo=2 and HC10otherseekcancerinfo=2 then selfproxy=4;
  else if hc9seekcancerinfo in (7,8,9) then selfproxy=hc9seekcancerinfo;
  else if HC10otherseekcancerinfo in (7,8,9) then selfproxy=HC10otherseekcancerinfo;

  ***Code for TimeSinceInfo was supplied by Richard Moser 02/18/2005;
  label TimeSinceInfo = 'Time since they last sought information';
  format timesinceinfo timesinc.;
  if hc12lastlookcancerinfo_unit=1 then timeseekinfo=hc12lastlookcancerinfo;
  if HC12lastlookcancerinfo_unit=2 then timeseekinfo=(hc12lastlookcancerinfo*7);
  if HC12lastlookcancerinfo_unit=3 then timeseekinfo=(hc12lastlookcancerinfo*30.5);
  if HC12lastlookcancerinfo_unit=4 then timeseekinfo=(HC12lastlookcancerinfo*365);
  timeseekinfomonths=(timeseekinfo/30.5);
  if hc12lastlookcancerinfo in (97,98,99) then TimeSinceInfo=hc12lastlookcancerinfo-90;
  else timesinceinfo=1*(0<timeseekinfomonths<=1) + 2*(1<timeseekinfomonths<=6) + 3*(6<timeseekinfomonths<=12)
  + 4*(12<timeseekinfomonths<=60) + 5*(60<timeseekinfomonths<500);
  if timesinceinfo=0 then timesinceinfo=.;
  drop timeseekinfo timeseekinfomonths;

  rename
  	FV1Fruit_t=Fruits
  	FV2FruitJuice_t=FruitJuice
  	FV3Vegetables_t=Vegetables
  	FV3aPotatoes_t=Potatoes
  	AgeGrp=AgeGrpA
  	AgeGrp5=AgeGrpB
  	HC12LastLookCancer_t=DaysSinceInfo
  	;
run;

proc sort data=extended;
  by caseno;
run;

data extended;
  merge extended raw.hints1_geo_data;
  by caseno;
run;

data ruralurb(keep=FIPS RUC2003);
  infile RURALURB dsd firstobs=2;
  input
    FIPS: $char5.
    State: $char2.
    CountyName: $char50.
    RUC1993
    RUC2003
    Pop2000: comma10.
    PctComm
    Desc2003: $char100.
    ;
  label RUC2003 = '2003 Rural-Urban Continuum Code (county-level, from Economic Research Service / USDA)';
  format RUC2003 RUC2003f.;
run;

proc sort data=extended;
  by FIPS;
run;

data extended(drop=region state);
  merge extended(in=inext) ruralurb;
  by FIPS;
  if inext;

  ***Census Division was missing for Alaska and Hawaii in the raw geographic data file.;
  if state in ('AK' 'HI') then division='9';

  format division $divis.;
run;

proc sort data=extended;
  by caseno;
run;

proc cimport file=SCREENER data=screener;

proc sort data=screener;
  by caseno;
run;

data extended;
  merge extended(in=inext) screener(keep=CaseNo InterviewDate);
  by caseno;
  if inext;
  label InterviewDate = 'Date of interview (DDMMYYYY)';

  tempintvyear = (input(substr(InterviewDate,5,4),4.));

  label CH3Age = 'Age diagnosed with cancer';
  format ch3age spage.;
  if CH1EverHadCancer ne 1 then CH3Age=.;
  else if SpAge in (997,998,999) then CH3Age=SpAge;
  else if CH3WhenDiagnosedCancer_Unit=1 then CH3Age = CH3WhenDiagnosedCancer_Age;
  else if CH3WhenDiagnosedCancer_Unit=2 then CH3Age = spage - (tempintvyear - CH3WhenDiagnosedCancer_Year);
  else if CH3WhenDiagnosedCancer_Unit=7 then CH3Age = 997; ***Not ascertained;
  else if CH3WhenDiagnosedCancer_Unit=9 then CH3Age = 999; ***Don't know;
  rename CH3Age=AgeDX;

  ***Code for timesincedx was supplied by Rick Moser 02/15/2005;
  label TimeSinceDx = 'Time since they were diagnosed with cancer';
  format TimeSinceDx timedx.;
  if ch3whendiagnosedcancer_age>88 then TimeSinceDx=ch3whendiagnosedcancer_age-990;
  else if ch3whendiagnosedcancer_unit in (7,8,9) then TimeSinceDx=ch3whendiagnosedcancer_unit;
  else if ch3whendiagnosedcancer_unit=1 then howlongCA=(spage-ch3whendiagnosedcancer_age);
  else if ch3whendiagnosedcancer_unit=2 then howlongCA=(tempintvyear-ch3whendiagnosedcancer_year);
  if TimeSinceDX not in (7,8,9) then timesincedx=1*(-1<=howlongCA=<1) + 2*(2<=howlongCA<=5)+ 3*(6<=howlongCA<=10) + 4*(HowlongCA>=11);
  if TimeSinceDX=0 then TimeSinceDX=.;
run;

data hc14(drop=freq);
  infile HC14 dsd firstobs=2;
  input HC14WhatLookCancerInfo : $char60. HC14A HC14B Freq;
  label HC14A = "What type of cancer information did you seek?(Rutten/Squiers recode A)";
  label HC14B = "What type of cancer information did you seek?(Rutten/Squiers recode B)";
  if compress(HC14WhatLookCancerInfo)='98' then HC14A=98;**Refused;
  else if compress(HC14WhatLookCancerInfo)='99' then HC14A=99;**Don't Know;
  format hc14a hc14a. hc14b hc14b.;
run;

proc sort data=hc14 nodupkey;
  by HC14WhatLookCancerInfo HC14A HC14B;
run;

proc sort data=extended;
  by HC14WhatLookCancerInfo;
run;

data extended;
  merge extended(in=inext) hc14;
  by HC14WhatLookCancerInfo;
run;

data fipsdma(keep=fips dma);
  infile FIPSDMA dsd firstobs=2;
  input fips: $char5. county $ state $ DMA;
  label DMA = 'Designated Market Area';
  format DMA DMA.;
run;

proc sort data=extended;
  by fips;
run;

proc sort data=fipsdma;
  by fips;
run;

data extended(drop=fips);
  merge extended(in=inextended) fipsdma;
  by fips;
  if inextended;
run;


**********************************************************************************;
***Add CancType variable.  This variable was devised by Whitney Randolph.  It     ;
***recodes CH2TypeOfSPsCancer01-CH2TypeOfSPsCancer04 and CH2TypeOfSPsCancer_OS    ;
***into a single variable.                                                        ;
**********************************************************************************;

proc cimport file=CANCTYPE data=canctype;

proc sort data=extended;
  by caseno;
run;

proc sort data=canctype;
  by caseno;
run;

data extended;
  merge extended canctype;
  by caseno;
  if CH2TypeOfSPsCancer01 in (97,98,99) then cancertype=CH2TypeOfSPsCancer01;
  else if cancertype=13 then cancertype=99;***Not Known --> Don't Know;
  format cancertype canctype.;
run;

**********************************************************************************;
ods rtf file=SOURCE;

%macro summarize(classlist);
  proc summary nway missing data=temp;
    class &classlist;
    output out=summ;
  run;

  proc print data=summ(drop=_TYPE_) obs="Obs" style(data)=[just=right] label;
  run;

%mend;

proc format;
  value racetest
    10 = 'AIAN'
    11 = 'Asian'
    12 = 'Black'
    13 = 'NHOPI'
    14 = 'White'
    97 = "NA"
    98 = "Ref"
    99 = "DK"
    ;
  value inctest
    1 = 'Yes'
    2 = 'No'
    7 = 'NA'
    8 = 'Ref'
    9 = 'DK'
    ;
  value hsgr
  	1 = "All"
  	2 = "Most"
  	3 = "Some"
  	4 = "Little"
  	5 = "None"
  	7 = "NA"
  	8 = "REF"
  	9 = "DK"
  	;
run;

data temp;
	set extended;
	label DM7dIncome10Thousand="<10K?"
		  DM7cIncome15Thousand="<15K?"
		  DM7bIncome20Thousand="<20K?"
		  DM7aIncome25Thousand="<25K?"
		  DM7eIncome35Thousand="<35K?"
		  DM7fIncome50Thousand="<50K?"
		  DM7gIncome75Thousand="<75K?"
		  DM7hIncomeOver75Thousand=">=75K?"
		  CH3WhenDiagnosedCancer_Unit="CH3Unit"
		  CH3WhenDiagnosedCancer_Year="CH3Year"
		  CH3WhenDiagnosedCancer_Age="CH3Age"
		  tempintvyear="intyear"
		  distressed="Dist."
		  distressScore="dScore"
		  ;
    format
    dm5race1-dm5race5 racetest.
    DM7aIncome25Thousand DM7bIncome20Thousand DM7cIncome15Thousand DM7dIncome10Thousand DM7eIncome35Thousand DM7fIncome50Thousand DM7gIncome75Thousand DM7hIncomeOver75Thousand inctest.
    HS2aSad HS2bNervous HS2cRestless HS2dHopeless HS2eEffort HS2fWorthless hsgr.
    ;
    run;

title2 'Checking new variables';

%summarize( agegrpA spage spagerange );
%summarize( educA DM6Education );
%summarize( distressed distressscore HS2aSad HS2bNervous HS2cRestless HS2dHopeless HS2eEffort HS2fWorthless);
%summarize( race dm5race1 dm5race2 dm5race3 dm5race4 dm5race5 );
%summarize( raceethn dm4hispanic dm5race1 dm5race2 dm5race3 dm5race4 dm5race5  );
%summarize( hhinca DM7aIncome25Thousand DM7bIncome20Thousand DM7cIncome15Thousand DM7dIncome10Thousand DM7eIncome35Thousand DM7fIncome50Thousand DM7gIncome75Thousand DM7hIncomeOver75Thousand  );
%summarize( hhincb DM7aIncome25Thousand DM7bIncome20Thousand DM7cIncome15Thousand DM7dIncome10Thousand DM7eIncome35Thousand DM7fIncome50Thousand DM7gIncome75Thousand DM7hIncomeOver75Thousand  );
%summarize( ruc2003  );
%summarize( division  );
%summarize( hc14whatlookcancerinfo hc14a hc14b  );
%summarize( AgeDX SpAge CH3WhenDiagnosedCancer_Unit CH3WhenDiagnosedCancer_Age CH3WhenDiagnosedCancer_Year tempintvyear );
%summarize( Fruits FV1Fruits_Unit FV1Fruits  );
%summarize( FruitJuice FV2FruitJuice_Unit FV2FruitJuice  );
%summarize( Vegetables FV3Vegetables_Unit FV3Vegetables  );
%summarize( Potatoes FV3aPotatoes_Unit FV3aPotatoes  );
%summarize( DaysSinceInfo HC12LastLookCancerInfo HC12LastLookCancerInfo_Unit  );
%summarize( HW1HeightInches_t HW1Height_Feet HW1Height_Inches  );
%summarize( agegrpB spage spagerange  );
%summarize( BMI HW1Height_Feet HW1Height_Inches HW2Weight  );
%summarize( timesincedx ch3whendiagnosedcancer_unit spage ch3whendiagnosedcancer_age ch3whendiagnosedcancer_year tempintvyear );
%summarize( timesinceinfo hc12lastlookcancerinfo_unit hc12lastlookcancerinfo  );
%summarize( selfproxy hc9seekcancerinfo HC10otherseekcancerinfo  );
%summarize( timesinceinfo hc12lastlookcancerinfo_unit hc12lastlookcancerinfo  );
%summarize( cancertype spgender ch1everhadcancer CH2TypeOfSPsCancer01-CH2TypeOfSPsCancer04 CH2TypeOfSPsCancer_OS );

ods rtf close;

title2;

data extended;
  set extended(drop=tempintvyear howlongca);
run;

proc freq data=extended(drop=caseno fwgt fwgt1-fwgt50);
  tables _all_ / missing;
run;

options center orientation=landscape;
ods pdf file=CONTENTS;

proc contents data=extended;
run;

ods pdf close;

proc cport data=extended file=OUTFILE1;
run;
